@@ -6,8 +6,9 @@ class TokenRefresher:
     _jwt_handler: JWTHandler
     _token: str
 
-    def __init__(self, service_account: ServiceAccount, seconds_before_expire: int, audience: str) -> None:
-        self._jwt_handler = JWTHandler(service_account, seconds_before_expire, audience)
+    def __init__(self, service_account: ServiceAccount, seconds_before_expire: int, audience: str,
+                 token_duration: int) -> None:
+        self._jwt_handler = JWTHandler(service_account, seconds_before_expire, audience, token_duration)
         self._token = None
 
     def get_access_token(self):
